/*-------------------------------------------------------------------
Name......... rm161680.c
Author....... Marc Adams
Date......... 17/11/03
Description.. Ramp tables for a rm161680 reel
............. Ported from the Pluto 5 driver
-------------------------------------------------------------------*/

/*-------------------------------------------------------------------
DECLARATION FORMATS
Type defs........... UPPER CASE
#defines............ UPPER CASE
Global Functions.... GlobalFunction();
Static Functions.... staticfunction();
Global Variables.... GlobalVariable;
Static Variables.... staticvariable;
Local Variables..... localvariable;
Structure Elements.. Structure.element;
-------------------------------------------------------------------*/
/***	Include Files */

#include "hardware.h"
#include "peripherals.h"
#include "rm161680.h"

/*** Pattern tables */
static const   WORD    fullstep[]=
{
	0x0a,	/* a */
	0x09,   /* b */
	0x05,   /* c */
	0x06,   /* d */
};

static const   WORD    halfstep[]=
{
	0x020a,	/* a */
	0x0809,	/* b */
	0x0105,	/* c */
	0x0406,	/* d */
};

/***	Vector tables */

static void    (*const spin_vector_tbl[])(const void*)=
{
	(void (*)(const void*))Stabilize,
	(void (*)(const void*))RampUp,
	(void (*)(const void*))Run,
	(void (*)(const void*))RampDown,
	(void (*)(const void*))Idle1,
	(void (*)(const void*))Idle0,
};

static void    (*const nudge_vector_tbl[])(const void*)=
{
	(void (*)(const void*))Stabilize,
	(void (*)(const void*))RampUp,
	(void (*)(const void*))RampDown,
	(void (*)(const void*))Idle1,
	(void (*)(const void*))Idle0,
};

static void    (*const HS_nudge_vector_tbl[])(const void*)=
{
	(void (*)(const void*))Stabilize,
	(void (*)(const void*))HalfStep,
	(void (*)(const void*))Idle1,
	(void (*)(const void*))Idle0,
};

static void    (*const step_vector_tbl[])(const void*)=
{
	(void (*)(const void*))Stabilize,
	(void (*)(const void*))RampDown,
	(void (*)(const void*))Idle1,
	(void (*)(const void*))Idle0,
};

static void    (*const skill_spin_vector_tbl[])(const void*)=
{
	(void (*)(const void*))Stabilize,
	(void (*)(const void*))RampUp,
	(void (*)(const void*))SkillRun,
	(void (*)(const void*))RampDown,
	(void (*)(const void*))Idle1,
	(void (*)(const void*))Idle0,
};

static void    (*const wobble_vector_tbl[])(const void *)=
{
	(void (*)(const void*))Stabilize,
	(void (*)(const void*))WobbleRun,
	(void (*)(const void*))WobbleTmn,
	(void (*)(const void*))Idle1,
	(void (*)(const void*))Idle0,
};

static void    (*const HSwobble_vector_tbl[])(const void *)=
{
	(void (*)(const void*))Stabilize,
	(void (*)(const void*))HSwobble_run,
	(void (*)(const void*))HSwobble_tmn,
	(void (*)(const void*))Idle1,
	(void (*)(const void*))Idle0,
};

/***	Initialisation Ramp	*/
static const   WORD    Ramp_ini_delay_tbl[]=
{
	10,				/* Stabilize */
	4,47,28,18,26,	/* Ramp Up */
	1,18,			/* Run */
	4,23,20,48,     /* Ramp Down */
	100,			/* Settle time before duty cycle */
	20,20	  		/* Duty cycle */
};

static const   RAMP    Ramp_I=
{
	fullstep,
	full_step_mask,
	spin_vector_tbl,
	Ramp_ini_delay_tbl
};

/***    System Ramp	*/
static const   WORD    Ramp_sys_delay_tbl[]=
{
	10,				/* Stabilize */
	4,37,26,14,23,  /* Ramp Up */
	1,13,			/* Run */
	5,15,25,16,41,  /* Ramp Down */
	100,            /* Settle time before duty cycle */
	20,20  			/* Duty cycle */
};

static const   RAMP    Ramp_S=
{
	fullstep,
	full_step_mask,
	spin_vector_tbl,
	Ramp_sys_delay_tbl
};

/***	Ramp 69	*/
static const   WORD    Ramp_69_delay_tbl[]=
{
	10,				/* Stabilize */
	4,47,28,18,26,	/* Ramp Up */
	1,18,			/* Run */
	4,23,20,48,     /* Ramp Down */
	100,			/* Settle time before duty cycle */
	20,20	  		/* Duty cycle */
};

static const   RAMP    Ramp_69=
{
	fullstep,
	full_step_mask,
	spin_vector_tbl,
	Ramp_69_delay_tbl
};

/***    Ramp 78	*/
static const   WORD    Ramp_78_delay_tbl[]=
{
	10,				/* Stabilize */
	4,46,27,16,24,	/* Ramp Up */
	1,16,			/* Run */
	4,25,16,48,     /* Ramp Down */
	100, 			/* Settle time before duty cycle */
	20,20			/* Duty cycle */
};

static const   RAMP    Ramp_78=
{
	fullstep,
	full_step_mask,
	spin_vector_tbl,
	Ramp_78_delay_tbl
};

/***	Ramp 89	*/
static const   WORD    Ramp_89_delay_tbl[]=
{
	10,				/* Stabilize */
	4,38,24,14,25,  /* Ramp Up */
	1,14,			/* Run */
	4,26,14,46,		/* Ramp Down */
	100,			/* Settle time before duty cycle */
	20,20  			/* Duty cycle */
};

static const   RAMP    Ramp_89=
{
	fullstep,
	full_step_mask,
	spin_vector_tbl,
	Ramp_89_delay_tbl
};

/***	Ramp 96	*/
static const   WORD    Ramp_96_delay_tbl[]=
{
	10,				/* Stabilize */
	4,37,26,14,23,  /* Ramp Up */
	1,13,			/* Run */
	5,15,25,16,41,  /* Ramp Down */
	100,            /* Settle time before duty cycle */
	20,20  			/* Duty cycle */
};

static const   RAMP    Ramp_96=
{
	fullstep,
	full_step_mask,
	spin_vector_tbl,
	Ramp_96_delay_tbl
};

/***	Ramp 104 */
static const   WORD    Ramp_104_delay_tbl[]=
{
	10,				/* Stabilize */
	4,39,28,13,20,	/* Ramp Up */
	1,12,			/* Run */
	5,14,22,15,42,  /* Ramp Down */
	100,			/* Settle time before duty cycle */
	20,20			/* Duty cycle */
};

static const   RAMP    Ramp_104=
{
	fullstep,
	full_step_mask,
	spin_vector_tbl,
    Ramp_104_delay_tbl
};

/***	Nudge ramp */
static const   WORD    Ramp_nudge_delay_tbl[]=
{
	10,		/* Stabilize */
	1,45,	/* Ramp Up */
	2,57,	/* Ramp Down */
	200,	/* Settle time before duty cycle */
	20,20	/* Duty cycle */
};

static const   RAMP    Ramp_N=
{
	fullstep,
	full_step_mask,
	nudge_vector_tbl,
	Ramp_nudge_delay_tbl
};

/***	Half Step Nudge ramp */
static const   WORD    Ramp_HSN_delay_tbl[]=
{
	10,					/* Stabilize */
	6,42,30,24,30,44,	/* HalfStep	 */
	200,				/* Settle time before duty cycle */
	20,20				/* Duty cycle */
};

static const   RAMP    Ramp_HSN=
{
	halfstep,
	full_step_mask,
	HS_nudge_vector_tbl,
	Ramp_HSN_delay_tbl
};

/***	Wobble ramp	*/
static const   WORD    Ramp_wobble_delay_tbl[]=
{
	10,	 				/* Stabilize */
	2,0x8000+50, 50,	/* Wobble Run */
	2,0x8000+25, 15,	/* Wobble tmn */
	20,20				/* Duty cycle */
};

static const   RAMP    Ramp_wobble=
{
	fullstep,
	full_step_mask,
	wobble_vector_tbl,
	Ramp_wobble_delay_tbl
};

/***	HSWobble ramp */
static const   WORD    Ramp_HSwobble_delay_tbl[]=
{
	10,		 						/* Stabilize */
	4,0x8000+32,32,32,0x8000+32,	/* Wobble Run */
	2,0x8000+5,512,					/* Wobble tmn */
	20,20							/* Duty cycle */
};

static const   RAMP    Ramp_HSwobble=
{
	halfstep,
	half_step_mask,
	HSwobble_vector_tbl,
	Ramp_HSwobble_delay_tbl
};

/*************************************************************************/
/***	Skillslow ramp */
static const   WORD    Ramp_skillslow_delay_tbl[]=
{
	10,				/* Stabilize */
	4,47,28,18,26,	/* Ramp Up */
	1,18,			/* Run */
	4,23,20,48,     /* Ramp Down */
	100,			/* Settle time before duty cycle */
	20,20	  		/* Duty cycle */
};

static const   RAMP    Ramp_skillslow=
{
	fullstep,
	full_step_mask,
	skill_spin_vector_tbl,
	Ramp_skillslow_delay_tbl
};

/***	SkillMed ramp */
static const   WORD    Ramp_skillmed_delay_tbl[]=
{
	10,				/* Stabilize */
	4,46,27,16,24,	/* Ramp Up */
	1,16,			/* Run */
	4,25,16,48,     /* Ramp Down */
	100, 			/* Settle time before duty cycle */
	20,20			/* Duty cycle */
};

static const   RAMP    Ramp_skillmed=
{
	fullstep,
	full_step_mask,
	skill_spin_vector_tbl,
	Ramp_skillmed_delay_tbl
};

/***	Skillfast ramp */
static const   WORD    Ramp_skillfast_delay_tbl[]=
{
	10,				/* Stabilize */
	4,37,26,14,23,  /* Ramp Up */
	1,13,			/* Run */
	5,15,25,16,41,  /* Ramp Down */
	100,            /* Settle time before duty cycle */
	20,20  			/* Duty cycle */
};

static const   RAMP    Ramp_skillfast=
{
	fullstep,
	full_step_mask,
	skill_spin_vector_tbl,
	Ramp_skillfast_delay_tbl
};

const   REEL_TYPE       RM161680=
{
	48,					/* nof steps per rev */
	3,					/* nof steps per symbol */
	1,					/* time to see tab */
	2,					/* allowable error */
	TRUE,				/* correct position for reverse spin */
	&Ramp_I,	 		/* ramp - INI   */
	&Ramp_S,	 		/* ramp - SYS   */
	&Ramp_69,			/* ramp - 69    */
	&Ramp_78,			/* ramp - 78    */
	&Ramp_89,			/* ramp - 89    */
	&Ramp_96,			/* ramp - 96    */
	&Ramp_104,			/* ramp - 104   */
	&Ramp_HSN,			/* ramp - nudge1 */
	&Ramp_HSN,			/* ramp - nudge2 */
	&Ramp_HSN,			/* ramp - nudge3 */
	&Ramp_wobble,		/* ramp - Wobble */
	&Ramp_HSwobble,		/* ramp - Half Step Wobble */
	&Ramp_skillslow,	/* ramp - Skill stop  */
	&Ramp_skillmed, 	/* ramp - Skill stop  */
	&Ramp_skillfast,	/* ramp - Skill stop  */
};

/****************************************************************************/
